@@ -7,5 +7,5 @@ ES_CLASSPATH=$ES_CLASSPATH:$( find /usr/share/java \
     -or -name 'apache-log4j-extras-1.2.*.jar' \
     -or -name 'lucene-*-4.10.*.jar' \
     -or -name 'spatial4j-0.4*.jar' \
-    -or -name 'groovy-all-2.x.jar' \
+    -or -name 'groovy-all.jar' \
     | tr '\n' ':' | sed -e 's,::*,:,g' )
